==> transmission-1.42.tar.bz2: transmission-1.42/macosx/Badger.h <==
/******************************************************************************
 * $Id: Badger.h 7032 2008-11-04 01:31:24Z livings124 $
 *
 * Copyright (c) 2006-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import <transmission.h>

@interface Badger : NSObject
{
    tr_handle * fLib;
    
    NSUInteger fCompleted;
    
    //tiger-only fields
    NSImage * fDockIcon, * fBadge;
    NSDictionary * fAttributes;
    NSUInteger fCompletedBadged;
    BOOL fSpeedBadge, fQuittingTiger;
}

- (id) initWithLib: (tr_handle *) lib;

- (void) updateBadge;
- (void) incrementCompleted;
- (void) clearCompleted;
- (void) setQuitting;

@end

==> transmission-1.51.tar.bz2: transmission-1.51/macosx/Badger.h <==
/******************************************************************************
 * $Id: Badger.h 7666 2009-01-11 18:04:45Z livings124 $
 *
 * Copyright (c) 2006-2008 Transmission authors and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>
#import <transmission.h>

@interface Badger : NSObject
{
    tr_session * fLib;
    
    NSUInteger fCompleted;
    
    //tiger-only fields
    NSImage * fDockIcon, * fBadge;
    NSDictionary * fAttributes;
    NSUInteger fCompletedBadged;
    BOOL fSpeedBadge, fQuittingTiger;
}

- (id) initWithLib: (tr_session *) lib;

- (void) updateBadge;
- (void) incrementCompleted;
- (void) clearCompleted;
- (void) setQuitting;

@end
